@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2021 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2022 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -62,7 +62,7 @@ gboolean			asc_globals_add_hint_tag (const gchar *tag,
 							  AsIssueSeverity severity,
 							  const gchar *explanation,
 							  gboolean overrideExisting);
-gchar				**asc_globals_get_hint_tags ();
+gchar				**asc_globals_get_hint_tags (void);
 AsIssueSeverity			asc_globals_hint_tag_severity (const gchar *tag);
 const gchar			*asc_globals_hint_tag_explanation (const gchar *tag);
 
